@@ -61,25 +61,25 @@ def example_project(tmp_path):
 
 @pytest.fixture
 def example_pyproject_toml(example_project):
-    yield example_project / "pyproject.toml"
+    return example_project / "pyproject.toml"
 
 
 @pytest.fixture
 def example_setup_cfg(example_project):
-    yield example_project / "setup.cfg"
+    return example_project / "setup.cfg"
 
 
 @pytest.fixture
 def example_setup_py(example_project):
-    yield example_project / "setup.py"
+    return example_project / "setup.py"
 
 
 # Note this is just the path and the content may change
 @pytest.fixture
 def example_changelog_md(example_project):
-    yield example_project / "CHANGELOG.md"
+    return example_project / "CHANGELOG.md"
 
 
 @pytest.fixture
 def example_project_template_dir(example_project):
-    yield example_project / "templates"
+    return example_project / "templates"
