@@ -19,7 +19,7 @@ from tests.util import netrc_file
 @pytest.fixture
 def default_gitea_client():
     remote_url = f"git@gitea.com:{EXAMPLE_REPO_OWNER}/{EXAMPLE_REPO_NAME}.git"
-    yield Gitea(remote_url=remote_url)
+    return Gitea(remote_url=remote_url)
 
 
 @pytest.mark.parametrize(
@@ -89,9 +89,8 @@ def test_gitea_client_init(
         assert client.api_url == f"https://{client.hvcs_api_domain}"
         assert client.token == token
         assert client._remote_url == remote_url
-        assert hasattr(client, "session") and isinstance(
-            getattr(client, "session", None), Session
-        )
+        assert hasattr(client, "session")
+        assert isinstance(getattr(client, "session", None), Session)
 
 
 def test_gitea_get_repository_owner_and_name(default_gitea_client):
@@ -142,7 +141,14 @@ def test_gitea_get_repository_owner_and_name(default_gitea_client):
         ),
     ],
 )
-def test_remote_url(default_gitea_client, use_token, token, _remote_url, expected):
+def test_remote_url(
+    default_gitea_client,
+    use_token,
+    token,
+    # TODO: linter thinks this is a fixture not a param - why?
+    _remote_url,  # noqa: PT019
+    expected,
+):
     default_gitea_client._remote_url = _remote_url
     default_gitea_client.token = token
     assert default_gitea_client.remote_url(use_token=use_token) == expected
@@ -326,11 +332,7 @@ def test_request_has_no_auth_header_if_no_token_or_netrc():
             assert m.last_request.method == "POST"
             assert (
                 m.last_request.url
-                == "{api_url}/repos/{owner}/{repo_name}/releases".format(
-                    api_url=client.api_url,
-                    owner=client.owner,
-                    repo_name=client.repo_name,
-                )
+                == f"{client.api_url}/repos/{client.owner}/{client.repo_name}/releases"
             )
             assert "Authorization" not in m.last_request.headers
 
@@ -447,7 +449,6 @@ def test_create_or_update_release_when_create_succeeds(
         mock_create_release.return_value = mock_release_id
         mock_get_release_id_by_tag.return_value = mock_release_id
         mock_edit_release_notes.return_value = mock_release_id
-        # client = Github(remote_url="git@github.com:something/somewhere.git")
         assert (
             default_gitea_client.create_or_update_release(
                 tag, RELEASE_NOTES, prerelease
@@ -479,7 +480,6 @@ def test_create_or_update_release_when_create_fails_and_update_succeeds(
         mock_create_release.side_effect = not_found
         mock_get_release_id_by_tag.return_value = mock_release_id
         mock_edit_release_notes.return_value = mock_release_id
-        # client = Github(remote_url="git@github.com:something/somewhere.git")
         assert (
             default_gitea_client.create_or_update_release(
                 tag, RELEASE_NOTES, prerelease
@@ -533,7 +533,7 @@ def test_upload_asset_succeeds(
                 file=example_changelog_md.resolve(),
                 label="doesn't matter could be None",
             )
-            == True
+            is True
         )
         assert m.called
         assert len(m.request_history) == 1
